@@ -21,18 +21,10 @@ class EventViews(AbstractViews):
     _base_schema = base_schema
     _id_field = "id"
 
-    @view_config(
-        route_name="c2cgeoform_item",
-        request_method="GET",
-        renderer="getitfixed:templates/public/issues/edit.jinja2",
-    )
-    def edit(self):
-        return super().edit()
-
     @view_config(
         route_name="c2cgeoform_item",
         request_method="POST",
-        renderer="getitfixed:templates/public/issues/edit.jinja2",
+        renderer="getitfixed:templates/admin/events/edit.jinja2",
     )
     def save(self):
         resp = super().save()
@@ -61,8 +53,8 @@ class EventViews(AbstractViews):
                     self._obj.issue.email,
                     "update_issue_email",
                     self._request.route_url(
-                        "c2cgeoform_item_private",
-                        application="getitfixed",
+                        "c2cgeoform_item",
+                        application="getitfixed_private",
                         table="issues",
                         id=self._obj.issue.hash,
                         _anchor="existing_events_form",
@@ -86,9 +78,7 @@ class EventViews(AbstractViews):
             to=send_to,
             template_name=template_name,
             template_kwargs={
-                "username": "{} {}".format(
-                    self._obj.issue.firstname, self._obj.issue.lastname
-                ),
+                "username": self._obj.issue.full_name(),
                 "issue": self._obj.issue,
                 "event": self._obj,
                 "issue-link": link,
