@@ -84,15 +84,6 @@ class IssueViews(AbstractViews):
         ),
     ]
 
-    MSG_COL = {
-        "submit_ok": _(
-            "Thank you for your report, "
-            "it has been registered with following details, "
-            "and will be treated as soon as possible."
-        ),
-        "copy_ok": _("Please check that the copy fits before submitting."),
-    }
-
     def _base_query(self):
         return (
             super()
@@ -122,7 +113,7 @@ class IssueViews(AbstractViews):
 
     def _get_object(self):
         obj = super()._get_object()
-        if obj.private:
+        if obj.status == STATUS_NEW or obj.private:
             raise HTTPNotFound()
         return obj
 
@@ -142,8 +133,10 @@ class IssueViews(AbstractViews):
             if not self._request.matchdict["id"].isdigit():
                 raise HTTPNotFound()
             base_edit = super().edit(schema=follow_schema, readonly=True)
-            base_edit["item_name"] = self._get_object().description
+            obj = self._get_object()
+            base_edit["item_name"] = obj.description
             base_edit["new"] = False
+            base_edit["wms_layer"] = obj.type.wms_layer
             return base_edit
 
     # For development/testing purpose
@@ -164,17 +157,17 @@ class IssueViews(AbstractViews):
         renderer="getitfixed:templates/public/issues/edit.jinja2",
     )
     def save(self):
-        base_save = super().save()
+        resp = super().save()
         if self._is_new():
 
-            if isinstance(base_save, HTTPFound):
+            if isinstance(resp, HTTPFound):
                 # Send email to the issue Reporter
                 self.send_notification_email(
                     self._obj.email,
                     "new_issue_email",
                     self._request.route_url(
-                        "c2cgeoform_item_private",
-                        application="getitfixed",
+                        "c2cgeoform_item",
+                        application="getitfixed_private",
                         id=self._obj.hash,
                     ),
                 )
@@ -188,9 +181,17 @@ class IssueViews(AbstractViews):
                         id=self._obj.hash,
                     ),
                 )
-            else:
-                base_save["item_name"] = _("New")
-        return base_save
+                return HTTPFound(
+                    self._request.route_url(
+                        "c2cgeoform_item",
+                        application="getitfixed_private",
+                        id=self._obj.hash,
+                        _query=[("msg_col", "submit_ok")],
+                    )
+                )
+
+        resp.update({"item_name": _("New"), "new": self._is_new()})
+        return resp
 
     def send_notification_email(self, send_to, template_name, link):
         send_email(
@@ -198,7 +199,7 @@ class IssueViews(AbstractViews):
             to=send_to,
             template_name=template_name,
             template_kwargs={
-                "username": "{} {}".format(self._obj.firstname, self._obj.lastname),
+                "username": self._obj.full_name(),
                 "issue": self._obj,
                 "issue-link": link,
             },
